@@ -30,3 +30,13 @@ class JsonExporter(MetricExporter):
                                          "labels": metric.labels,
                                          "timestamp": metric.timestamp})
         return dic
+
+
+class PrometheusExporter(MetricExporter):
+    @classmethod
+    def export(cls, exprot_metrics: List[BaseMetric]) -> Dict[str, Any]:
+        try:
+            from prometheus_client import metrics, registry
+        except ImportError:
+            raise ImportError(
+                "You need to install prometheus-client to use PrometheusExporter (web-foundation[prometheus])")
