@@ -17,6 +17,7 @@ class IMessage:
     inner_index: int
     sender: str
     destination: str = "__all__"
+    exec_inner: bool = False
 
     def __init__(self):
         self.index = 0
@@ -100,6 +101,10 @@ class IChannel:
         before_middleware = self._before_event_middlewares.get(msg.message_type)
         if before_middleware:
             await before_middleware(msg)
+        if msg.exec_inner:
+            listeners = self._listeners.get(msg.message_type)
+            for listener in listeners:
+                asyncio.create_task(listener(msg))
         await self.produce_pipe.write(msg)
 
     async def sent_to_consume(self, msg: IMessage):
