@@ -40,7 +40,6 @@ class WriteableObj:
 
 
 class RtConnection(Generic[GenericIMessage]):
-    # debug: bool
     ping_timeout: float
     listen_timeout: float
     writeable: WriteableObj
@@ -61,7 +60,6 @@ class RtConnection(Generic[GenericIMessage]):
         self.writeable = writeable
         self.resolve_callback = resolve_callback
         self.input_ctx = input_ctx
-        # self.debug = debug
         self.ping_enable = ping_enable
         self.ping_timeout = ping_timeout if ping_timeout else 5
         self.listen_timeout = listen_timeout if listen_timeout else 0.1
@@ -106,8 +104,7 @@ class RtConnection(Generic[GenericIMessage]):
                                 resolve_callback: RtEventCallback = None,
                                 ping_enable: bool = True,
                                 ping_timeout=None,
-                                listen_timeout=None,
-                                debug: bool = False) -> RtConnection:
+                                listen_timeout=None) -> RtConnection:
         raise NotImplementedError
 
     @classmethod
