@@ -61,11 +61,11 @@ class SseRtConnection(RtConnection):
                                 resolve_callback: RtEventCallback = None,
                                 headers=None,
                                 ping_enable: bool = True, ping_timeout=None,
-                                listen_timeout=None, debug: bool = False) -> SseRtConnection:
+                                listen_timeout=None) -> SseRtConnection:
         writeable = await cls._construct_writable(input_ctx, headers=headers)
         instance = cls(input_ctx=input_ctx, writeable=writeable, resolve_callback=resolve_callback,
                        ping_enable=ping_enable, ping_timeout=ping_timeout,
-                       listen_timeout=listen_timeout, debug=debug)
+                       listen_timeout=listen_timeout)
         return instance
 
     @classmethod
